diff --git a/river/.config/river/init b/river/.config/river/init
index 1ce74c7..f5d369a 100755
--- a/river/.config/river/init
+++ b/river/.config/river/init
@@ -65,6 +65,7 @@ gsettings set org.gnome.desktop.interface cursor-theme 'Wii-Pointer-P1'
 
 ## Inputs
 riverctl focus-follows-cursor disabled
+riverctl set-cursor-warp on-output-change
 
 # Logitech G703
 riverctl input pointer-1133-16518-Logitech_G703_LS accel-profile flat
@@ -93,6 +94,7 @@ riverctl map normal Control+Shift Escape spawn "$TERMINAL -e btop"
 # Screenshots
 mkdir -p ~/Pictures/Screenshots # Make screenshots folder if missing
 riverctl map normal None Print spawn "~/config/screenshot.sh ~/Pictures/Screenshots full true"
+riverctl map normal Super Print spawn "~/config/screenshot.sh ~/Pictures/Screenshots display true"
 riverctl map normal Alt Print spawn "~/config/screenshot.sh ~/Pictures/Screenshots region true"
 
 # Clipboard
diff --git a/screenshot.sh b/screenshot.sh
index 2becc43..068360c 100755
--- a/screenshot.sh
+++ b/screenshot.sh
@@ -1,3 +1,5 @@
+#!/usr/bin/env bash
+
 # pancakes' wayland screenshot script
 # takes screenshots, saves them, copies to clipboard, and notifies you
 # depends on grim, libnotify, slurp, and wl-copy
@@ -5,22 +7,30 @@
 set -e
 
 if [ -z $2 ]; then
-    echo "Usage: $0 path full|region [notify=true|false]"
+    echo "Usage: $0 path full|display|region [notify=true|false]"
     exit
 fi
 
 FILENAME="$1/$(date +%F_%H-%M-%S)_$2.png"
 
-if [ $2 = "full" ]; then
-    # capture full screen screenshot with cursor
-    grim -c $FILENAME
-elif [ $2 = "region" ]; then
-    # capture screenshot of slurped region
-    grim -g "$(slurp)" $FILENAME
-else
-    echo "Mode must be either full or region"
-    exit
-fi
+case $2 in
+    "full")
+        # capture full screen screenshot with cursor
+        grim -c $FILENAME
+        ;;
+    "display")
+        # capture display screenshot with cursor
+        grim -c -g "$(slurp -o)" $FILENAME
+        ;;
+    "region")
+        # capture screenshot of slurped region
+        grim -g "$(slurp)" $FILENAME
+        ;;
+    *)
+        echo "Mode must be either full, display, or region"
+        exit
+        ;;
+esac
 
 NOTIFY=$3
 if [ ${NOTIFY:=false} = true ]; then